@@ -9,6 +9,7 @@ DEVICE_TYPE_PURE_COOL = "438"
 DEVICE_TYPE_PURE_COOL_FORMALDEHYDE = "438E"
 DEVICE_TYPE_PURE_COOL_DESK = "520"
 DEVICE_TYPE_PURE_HUMIDIFY_COOL = "358"
+DEVICE_TYPE_PURIFIER_HUMIDIFY_COOL_FORMALDEHYDE = "358E"
 DEVICE_TYPE_PURE_HOT_COOL_LINK = "455"
 DEVICE_TYPE_PURE_HOT_COOL = "527"
 DEVICE_TYPE_PURE_HOT_COOL_NEW = "527E"
@@ -25,6 +26,7 @@ DEVICE_TYPE_NAMES = {
     DEVICE_TYPE_PURE_HOT_COOL_NEW: "Pure Hot+Cool (New)",
     DEVICE_TYPE_PURE_HOT_COOL_LINK: "Pure Hot+Cool Link",
     DEVICE_TYPE_PURE_HUMIDIFY_COOL: "Pure Humidify+Cool",
+    DEVICE_TYPE_PURIFIER_HUMIDIFY_COOL_FORMALDEHYDE: "Purifier Humidify+Cool Formaldehyde",
 }
 
 ENVIRONMENTAL_OFF = -1
